@@ -17,6 +17,7 @@ def main():
 
     config = {
         "persistent": persistent,
+        "persistent_dir": persistent.persistent_dir,
         "device_address": selected_address if have_selected_device else env_address,
         "device_serial": selected_serial if have_selected_device else None,
         "have_selected_device": have_selected_device
@@ -44,7 +45,7 @@ def main():
     check_for_updates(config["persistent"])
 
     # warn user if no device is selected
-    if args.root_command != 'device':
+    if commands[args.root_command].needs_device(args):
         serial_at_address = get_device_serial(config['device_address'])
         if serial_at_address is None:
             eprint(f"Error: No device reachable at {config['device_address']}.\n"
