@@ -1,3 +1,4 @@
+import os.path
 from pathlib import Path
 import json
 import hashlib
@@ -24,7 +25,8 @@ class PersistentState:
             self._initialized = False
             return
         self._initialized = True
-        self._config_path = user_home / ".auterion-cli"
+        self.persistent_dir = user_home / ".auterion-cli"
+        self._config_path = self.persistent_dir / "persistent.json"
 
         self._config = {}
         self._load_hash = ''
@@ -60,6 +62,13 @@ class PersistentState:
         if persist_hash == self._load_hash:
             return
 
+        # Older auterion-cli had .auterion-cli as a file. Remove that file if it exists
+        if self.persistent_dir.exists() and self.persistent_dir.is_file():
+            os.unlink(self.persistent_dir)
+
+        if not self.persistent_dir.exists():
+            os.mkdir(self.persistent_dir)
+
         with open(self._config_path, 'w') as f:
             f.write(contents)
 
